@@ -5,7 +5,9 @@ from sometools.log_tools.logger_main import GeneralLog
 from sometools.datetime_tools.date_conversion import GeneralDatetime
 from sometools.chinese_to_pinyin_acronym.chinese_to_pinyin import GeneralChineseToPinyin
 from sometools.traditional_simplified_chinese_conversion.traditional_simplified_chinese import GeneralTraditionalSimplifiedChinese
+from sometools.url_tools.url_encode_decode import GeneralUrlEncodeDecode
 
-class Common_tools(GeneralChineseToPinyin, GeneralTraditionalSimplifiedChinese, GeneralDatetime, GeneralString, GeneralLog):
+
+class Common_tools(GeneralChineseToPinyin, GeneralTraditionalSimplifiedChinese, GeneralUrlEncodeDecode, GeneralDatetime, GeneralString, GeneralLog):
     def __init__(self, *args, **kwargs):
         super(Common_tools, self).__init__(*args, **kwargs)
